@@ -21,7 +21,6 @@ class ListboardViewError(Exception):
 
 
 class BaseListboardView(TemplateRequestContextMixin, ListView):
-
     cleaned_search_term: str | None = None
     context_object_name: str = "results"
     empty_queryset_message: str = _("Nothing to display.")
@@ -34,7 +33,7 @@ class BaseListboardView(TemplateRequestContextMixin, ListView):
     listboard_panel_style: str = "default"
     listboard_fa_icon: str | None = None
     listboard_model: str | None = None  # label_lower model name or model class
-    listboard_model_manager_name: str = "_default_manager"
+    listboard_model_manager_name: str = "on_site"
     listboard_panel_title: str | None = None
     listboard_instructions: str | None = None
 
