@@ -17,7 +17,6 @@ class SubjectListboardView(
     SearchFormViewMixin,
     ListboardView,
 ):
-
     listboard_model = get_consent_model_name()
     model_wrapper_cls = SubjectConsentModelWrapper
 
@@ -30,6 +29,10 @@ class SubjectListboardView(
     navbar_selected_item = "consented_subject"
     search_form_url = "subject_listboard_url"
 
+    name_search_field: str = "first_name"
+    identity_regex: str = r"^[0-9]+$"
+    identity_fields = ["identity"]
+
     def get_queryset_filter_options(self, request, *args, **kwargs):
         options = super().get_queryset_filter_options(request, *args, **kwargs)
         if kwargs.get("subject_identifier"):
@@ -37,17 +40,19 @@ class SubjectListboardView(
         return options
 
     def extra_search_options(self, search_term):
+        search_term = search_term.strip()
         q_objects = [
             Q(user_created__iexact=search_term),
             Q(user_modified__iexact=search_term),
         ]
-        if re.match(r"^[A-Za-z\-]+$", search_term):
+        if re.match(r"^[A-Za-z\-\s]+$", search_term):
             q_objects.append(Q(initials__exact=search_term.upper()))
-            q_objects.append(Q(first_name__exact=search_term.upper()))
+            q_objects.append(Q(**{f"{self.name_search_field}__exact": search_term.upper()}))
             q_objects.append(
                 Q(screening_identifier__icontains=search_term.replace("-", "").upper())
             )
             q_objects.append(Q(subject_identifier__icontains=search_term))
-        if re.match(r"^[0-9]+$", search_term):
-            q_objects.append(Q(identity__exact=search_term))
+        if re.match(self.identity_regex, search_term):
+            for field in self.identity_fields:
+                q_objects.append(Q(**{f"{field}__exact": search_term}))
         return q_objects
